/// <reference types="node" />
import { EventEmitter } from 'events';
import { ScanStream, ScanStreamOptions } from './scan-stream';
import { Redis } from 'ioredis';
import { RedisStats, BatchStats } from './stats';
import { ScanIterableOptions } from './scan-iterable';
export { BatchStats };
export { ScanIterableOptions, ScanStreamOptions };
export declare type statsLogger = (stats: RedisStats) => void;
declare type stringable = number | string | Buffer;
export interface IRedisLoaderOptions {
    redis: Redis;
    logger?: statsLogger;
    maxBatchSize?: number;
}
export declare class RedisLoader implements EventEmitter {
    stats: RedisStats;
    redis: Redis;
    private logger;
    private dataLoader;
    constructor({ redis, logger, maxBatchSize }: IRedisLoaderOptions);
    resetStats(): void;
    readonly _redis: Redis;
    private startBatch;
    private endBatch;
    private logStats;
    batchFunction(commands: stringable[][]): Promise<any>;
    private executeMulti;
    private executeSingle;
    bitcount: (key: stringable, start?: stringable, end?: stringable) => Promise<number>;
    bitcountBuffer: (key: stringable, start?: stringable, end?: stringable) => Promise<number>;
    get: (key: stringable) => Promise<string>;
    getBuffer: (key: stringable) => Promise<string>;
    set: (key: stringable, value: stringable, ...args: stringable[]) => any;
    setBuffer: (key: stringable, value: stringable, ...args: stringable[]) => any;
    setnx: (key: stringable, value: stringable) => Promise<any>;
    setnxBuffer: (key: stringable, value: stringable) => Promise<any>;
    setex: (key: stringable, seconds: stringable, value: stringable) => Promise<any>;
    setexBuffer: (key: stringable, seconds: stringable, value: stringable) => Promise<any>;
    psetex: (key: stringable, milliseconds: stringable, value: stringable) => Promise<any>;
    psetexBuffer: (key: stringable, milliseconds: stringable, value: stringable) => Promise<any>;
    append: (key: stringable, value: stringable) => Promise<number>;
    appendBuffer: (key: stringable, value: stringable) => Promise<number>;
    strlen: (key: stringable) => Promise<number>;
    strlenBuffer: (key: stringable) => Promise<number>;
    del: (...keys: stringable[]) => any;
    delBuffer: (...keys: stringable[]) => any;
    dump: (key: stringable) => Promise<string>;
    dumpBuffer: (key: stringable) => Promise<string>;
    exists: (...keys: stringable[]) => any;
    existsBuffer: (...keys: stringable[]) => any;
    setbit: (key: stringable, offset: stringable, value: stringable) => Promise<number>;
    setbitBuffer: (key: stringable, offset: stringable, value: stringable) => Promise<number>;
    getbit: (key: stringable, offset: stringable) => Promise<number>;
    getbitBuffer: (key: stringable, offset: stringable) => Promise<number>;
    setrange: (key: stringable, offset: stringable, value: stringable) => Promise<number>;
    setrangeBuffer: (key: stringable, offset: stringable, value: stringable) => Promise<number>;
    getrange: (key: stringable, start: stringable, end: stringable) => Promise<string>;
    getrangeBuffer: (key: stringable, start: stringable, end: stringable) => Promise<string>;
    substr: (key: stringable, start: stringable, end: stringable) => Promise<string>;
    substrBuffer: (key: stringable, start: stringable, end: stringable) => Promise<string>;
    incr: (key: stringable) => Promise<number>;
    incrBuffer: (key: stringable) => Promise<number>;
    decr: (key: stringable) => Promise<number>;
    decrBuffer: (key: stringable) => Promise<number>;
    mget: (...keys: stringable[]) => any;
    mgetBuffer: (...keys: stringable[]) => any;
    incrby: (key: stringable, increment: stringable) => Promise<number>;
    incrbyBuffer: (key: stringable, increment: stringable) => Promise<number>;
    incrbyfloat: (key: stringable, increment: stringable) => Promise<number>;
    incrbyfloatBuffer: (key: stringable, increment: stringable) => Promise<number>;
    decrby: (key: stringable, decrement: stringable) => Promise<number>;
    decrbyBuffer: (key: stringable, decrement: stringable) => Promise<number>;
    getset: (key: stringable, value: stringable) => Promise<string>;
    getsetBuffer: (key: stringable, value: stringable) => Promise<string>;
    mset: (key: stringable, value: stringable, ...args: stringable[]) => any;
    msetBuffer: (key: stringable, value: stringable, ...args: stringable[]) => any;
    msetnx: (key: stringable, value: stringable, ...args: stringable[]) => any;
    msetnxBuffer: (key: stringable, value: stringable, ...args: stringable[]) => any;
    rpush: (key: stringable, ...values: stringable[]) => any;
    rpushBuffer: (key: stringable, ...values: stringable[]) => any;
    lpush: (key: stringable, ...values: stringable[]) => any;
    lpushBuffer: (key: stringable, ...values: stringable[]) => any;
    rpushx: (key: stringable, value: stringable) => Promise<number>;
    rpushxBuffer: (key: stringable, value: stringable) => Promise<number>;
    lpushx: (key: stringable, value: stringable) => Promise<number>;
    lpushxBuffer: (key: stringable, value: stringable) => Promise<number>;
    linsert: (key: stringable, direction: "BEFORE" | "AFTER", pivot: stringable, value: stringable) => Promise<number>;
    linsertBuffer: (key: stringable, direction: "BEFORE" | "AFTER", pivot: stringable, value: stringable) => Promise<number>;
    rpop: (key: stringable) => Promise<string>;
    rpopBuffer: (key: stringable) => Promise<string>;
    lpop: (key: stringable) => Promise<string>;
    lpopBuffer: (key: stringable) => Promise<string>;
    brpop: (...keys: stringable[]) => any;
    brpopBuffer: (...keys: stringable[]) => any;
    blpop: (...keys: stringable[]) => any;
    blpopBuffer: (...keys: stringable[]) => any;
    brpoplpush: (source: stringable, destination: stringable, timeout: stringable) => Promise<any>;
    brpoplpushBuffer: (source: stringable, destination: stringable, timeout: stringable) => Promise<any>;
    llen: (key: stringable) => Promise<number>;
    llenBuffer: (key: stringable) => Promise<number>;
    lindex: (key: stringable, index: stringable) => Promise<string>;
    lindexBuffer: (key: stringable, index: stringable) => Promise<string>;
    lset: (key: stringable, index: stringable, value: stringable) => Promise<any>;
    lsetBuffer: (key: stringable, index: stringable, value: stringable) => Promise<any>;
    lrange: (key: stringable, start: stringable, stop: stringable) => Promise<any>;
    lrangeBuffer: (key: stringable, start: stringable, stop: stringable) => Promise<any>;
    ltrim: (key: stringable, start: stringable, stop: stringable) => Promise<any>;
    ltrimBuffer: (key: stringable, start: stringable, stop: stringable) => Promise<any>;
    lrem: (key: stringable, count: stringable, value: stringable) => Promise<number>;
    lremBuffer: (key: stringable, count: stringable, value: stringable) => Promise<number>;
    rpoplpush: (source: stringable, destination: stringable) => Promise<string>;
    rpoplpushBuffer: (source: stringable, destination: stringable) => Promise<string>;
    sadd: (key: stringable, ...members: stringable[]) => any;
    saddBuffer: (key: stringable, ...members: stringable[]) => any;
    srem: (key: stringable, ...members: stringable[]) => any;
    sremBuffer: (key: stringable, ...members: stringable[]) => any;
    smove: (source: stringable, destination: stringable, member: stringable) => Promise<string>;
    smoveBuffer: (source: stringable, destination: stringable, member: stringable) => Promise<string>;
    sismember: (key: stringable, member: stringable) => Promise<1 | 0>;
    sismemberBuffer: (key: stringable, member: stringable) => Promise<1 | 0>;
    scard: (key: stringable) => Promise<number>;
    scardBuffer: (key: stringable) => Promise<number>;
    spop: (key: stringable, count?: stringable) => Promise<any>;
    spopBuffer: (key: stringable, count?: stringable) => Promise<any>;
    srandmember: (key: stringable, count?: stringable) => Promise<any>;
    srandmemberBuffer: (key: stringable, count?: stringable) => Promise<any>;
    sinter: (...keys: stringable[]) => any;
    sinterBuffer: (...keys: stringable[]) => any;
    sinterstore: (destination: stringable, ...keys: stringable[]) => any;
    sinterstoreBuffer: (destination: stringable, ...keys: stringable[]) => any;
    sunion: (...keys: stringable[]) => any;
    sunionBuffer: (...keys: stringable[]) => any;
    sunionstore: (destination: stringable, ...keys: stringable[]) => any;
    sunionstoreBuffer: (destination: stringable, ...keys: stringable[]) => any;
    sdiff: (...keys: stringable[]) => any;
    sdiffBuffer: (...keys: stringable[]) => any;
    sdiffstore: (destination: stringable, ...keys: stringable[]) => any;
    sdiffstoreBuffer: (destination: stringable, ...keys: stringable[]) => any;
    smembers: (key: stringable) => Promise<any>;
    smembersBuffer: (key: stringable) => Promise<any>;
    sscan: (key: stringable, cursor: stringable, ...args: stringable[]) => [string, string[]];
    sscanBuffer: (key: stringable, cursor: stringable, ...args: stringable[]) => [Buffer, Buffer[]];
    sscanStream: (options?: ScanStreamOptions) => ScanStream;
    sscanBufferStream: (options?: ScanStreamOptions) => ScanStream;
    sscanIterable: (options?: ScanIterableOptions) => AsyncIterableIterator<string[]>;
    sscanBufferIterable: (options?: ScanIterableOptions) => AsyncIterableIterator<Buffer[]>;
    zadd: (key: stringable, ...args: stringable[]) => any;
    zaddBuffer: (key: stringable, ...args: stringable[]) => any;
    zincrby: (key: stringable, increment: stringable, member: stringable) => Promise<any>;
    zincrbyBuffer: (key: stringable, increment: stringable, member: stringable) => Promise<any>;
    zrem: (key: stringable, ...members: stringable[]) => any;
    zremBuffer: (key: stringable, ...members: stringable[]) => any;
    zremrangebyscore: (key: stringable, min: stringable, max: stringable) => Promise<any>;
    zremrangebyscoreBuffer: (key: stringable, min: stringable, max: stringable) => Promise<any>;
    zremrangebyrank: (key: stringable, start: stringable, stop: stringable) => Promise<any>;
    zremrangebyrankBuffer: (key: stringable, start: stringable, stop: stringable) => Promise<any>;
    zunionstore: (destination: stringable, numkeys: stringable, key: stringable, ...args: stringable[]) => any;
    zunionstoreBuffer: (destination: stringable, numkeys: stringable, key: stringable, ...args: stringable[]) => any;
    zinterstore: (destination: stringable, numkeys: stringable, ...args: stringable[]) => any;
    zinterstoreBuffer: (destination: stringable, numkeys: stringable, ...args: stringable[]) => any;
    zrange: (key: stringable, start: stringable, stop: stringable, withScores?: "WITHSCORES") => Promise<any>;
    zrangeBuffer: (key: stringable, start: stringable, stop: stringable, withScores?: "WITHSCORES") => Promise<any>;
    zrevrange: (key: stringable, start: stringable, stop: stringable, withScores?: "WITHSCORES") => Promise<any>;
    zrevrangeBuffer: (key: stringable, start: stringable, stop: stringable, withScores?: "WITHSCORES") => Promise<any>;
    zrangebyscore: (key: stringable, min: stringable, max: stringable, ...args: (string | stringable)[]) => any;
    zrangebyscoreBuffer: (key: stringable, min: stringable, max: stringable, ...args: (string | stringable)[]) => any;
    zrevrangebyscore: (key: stringable, max: stringable, min: stringable, ...args: (string | stringable)[]) => any;
    zrevrangebyscoreBuffer: (key: stringable, max: stringable, min: stringable, ...args: (string | stringable)[]) => any;
    zrangebylex: (key: stringable, min: stringable, max: stringable, ...args: (string | stringable)[]) => any;
    zrangebylexBuffer: (key: stringable, min: stringable, max: stringable, ...args: (string | stringable)[]) => any;
    zrevrangebylex: (key: stringable, max: stringable, min: stringable, ...args: (string | stringable)[]) => any;
    zrevrangebylexBuffer: (key: stringable, max: stringable, min: stringable, ...args: (string | stringable)[]) => any;
    zcount: (key: stringable, min: stringable, max: stringable) => Promise<number>;
    zcountBuffer: (key: stringable, min: stringable, max: stringable) => Promise<number>;
    zlexcount: (key: stringable, min: stringable, max: stringable) => Promise<number>;
    zlexcountBuffer: (key: stringable, min: stringable, max: stringable) => Promise<number>;
    zcard: (key: stringable) => Promise<number>;
    zcardBuffer: (key: stringable) => Promise<number>;
    zscore: (key: stringable, member: stringable) => Promise<number>;
    zscoreBuffer: (key: stringable, member: stringable) => Promise<number>;
    zrank: (key: stringable, member: stringable) => Promise<number>;
    zrankBuffer: (key: stringable, member: stringable) => Promise<number>;
    zrevrank: (key: stringable, member: stringable) => Promise<number>;
    zrevrankBuffer: (key: stringable, member: stringable) => Promise<number>;
    zpopmax: (key: stringable, count?: stringable) => any;
    zpopmaxBuffer: (key: stringable, count?: stringable) => any;
    zpopmin: (key: stringable, count?: stringable) => any;
    zpopminBuffer: (key: stringable, count?: stringable) => any;
    bzpopmax: (key: stringable, ...keysOrTimeout: stringable[]) => any;
    bzpopmaxBuffer: (key: stringable, ...keysOrTimeout: stringable[]) => any;
    bzpopmin: (key: stringable, ...keysOrTimeout: stringable[]) => any;
    bzpopminBuffer: (key: stringable, ...keysOrTimeout: stringable[]) => any;
    zscan: (key: stringable, cursor: stringable, ...args: stringable[]) => [string, string[]];
    zscanBuffer: (key: stringable, cursor: stringable, ...args: stringable[]) => [Buffer, Buffer[]];
    zscanStream: (key: stringable, options?: ScanStreamOptions) => ScanStream;
    zscanBufferStream: (key: stringable, options?: ScanStreamOptions) => ScanStream;
    zscanIterable: (key: stringable, options?: ScanIterableOptions) => AsyncIterableIterator<string[]>;
    zscanBufferIterable: (key: stringable, options?: ScanIterableOptions) => AsyncIterableIterator<Buffer[]>;
    hset: (key: stringable, field: stringable, value: stringable) => Promise<0 | 1>;
    hsetBuffer: (key: stringable, field: stringable, value: stringable) => Promise<0 | 1>;
    hsetnx: (key: stringable, field: stringable, value: stringable) => Promise<0 | 1>;
    hsetnxBuffer: (key: stringable, field: stringable, value: stringable) => Promise<0 | 1>;
    hget: (key: stringable, field: stringable) => Promise<string>;
    hgetBuffer: (key: stringable, field: stringable) => Promise<string>;
    hmset: (key: stringable, fieldOrObj: stringable | object, value?: stringable, ...args: stringable[]) => Promise<0 | 1>;
    hmsetBuffer: (key: stringable, fieldOrObj: stringable | object, value?: stringable, ...args: stringable[]) => Promise<0 | 1>;
    hmget: (key: stringable, ...fields: stringable[]) => any;
    hmgetBuffer: (key: stringable, ...fields: stringable[]) => any;
    hincrby: (key: stringable, field: stringable, increment: stringable) => Promise<number>;
    hincrbyBuffer: (key: stringable, field: stringable, increment: stringable) => Promise<number>;
    hincrbyfloat: (key: stringable, field: stringable, increment: stringable) => Promise<number>;
    hincrbyfloatBuffer: (key: stringable, field: stringable, increment: stringable) => Promise<number>;
    hdel: (key: stringable, ...fields: stringable[]) => any;
    hdelBuffer: (key: stringable, ...fields: stringable[]) => any;
    hlen: (key: stringable) => Promise<number>;
    hlenBuffer: (key: stringable) => Promise<number>;
    hkeys: (key: stringable) => Promise<any>;
    hkeysBuffer: (key: stringable) => Promise<any>;
    hvals: (key: stringable) => Promise<any>;
    hvalsBuffer: (key: stringable) => Promise<any>;
    hgetall: (key: stringable) => Promise<any>;
    hgetallBuffer: (key: stringable) => Promise<any>;
    hexists: (key: stringable, field: stringable) => Promise<0 | 1>;
    hexistsBuffer: (key: stringable, field: stringable) => Promise<0 | 1>;
    hscan: (key: stringable, cursor: stringable, ...args: stringable[]) => [string, string[]];
    hscanBuffer: (key: stringable, cursor: stringable, ...args: stringable[]) => [Buffer, Buffer[]];
    hscanStream: (key: stringable, options?: ScanStreamOptions) => ScanStream;
    hscanBufferStream: (key: stringable, options?: ScanStreamOptions) => ScanStream;
    hscanIterable: (key: stringable, options?: ScanIterableOptions) => AsyncIterableIterator<string[]>;
    hscanBufferIterable: (key: stringable, options?: ScanIterableOptions) => AsyncIterableIterator<Buffer[]>;
    pfmerge: (destkey: stringable, ...sourcekeys: stringable[]) => any;
    pfmergeBuffer: (destkey: stringable, ...sourcekeys: stringable[]) => any;
    pfadd: (key: stringable, ...elements: stringable[]) => any;
    pfaddBuffer: (key: stringable, ...elements: stringable[]) => any;
    pfcount: (...keys: stringable[]) => any;
    pfcountBuffer: (...keys: stringable[]) => any;
    xack: (key: stringable, group: stringable, ...ids: stringable[]) => any;
    xackBuffer: (key: stringable, group: stringable, ...ids: stringable[]) => any;
    xadd: (key: stringable, id: stringable | number, ...fieldAndString: Array<string>) => any;
    xaddBuffer: (key: stringable, id: stringable | number, ...fieldAndString: Array<string>) => any;
    xclaim: (...args: stringable[]) => any;
    xclaimBuffer: (...args: stringable[]) => any;
    xdel: (key: stringable, ...ids: stringable[]) => any;
    xdelBuffer: (key: stringable, ...ids: stringable[]) => any;
    xgroup: (...args: stringable[]) => any;
    xgroupBuffer: (...args: stringable[]) => any;
    xinfo: (...args: stringable[]) => any;
    xinfoBuffer: (...args: stringable[]) => any;
    xlen: (key: stringable) => any;
    xlenBuffer: (key: stringable) => any;
    xpending: (key: stringable, group: stringable, ...args: stringable[]) => any;
    xpendingBuffer: (key: stringable, group: stringable, ...args: stringable[]) => any;
    xrange: (key: stringable, start: stringable, end: stringable, COUNT?: "COUNT", count?: stringable) => any;
    xrangeBuffer: (key: stringable, start: stringable, end: stringable, COUNT?: "COUNT", count?: stringable) => any;
    xread: (...args: stringable[]) => any;
    xreadBuffer: (...args: stringable[]) => any;
    xreadgroup: (...args: stringable[]) => any;
    xreadgroupBuffer: (...args: stringable[]) => any;
    xrevrange: (key: stringable, start: stringable, end: stringable, COUNT?: "COUNT", count?: stringable) => any;
    xrevrangeBuffer: (key: stringable, start: stringable, end: stringable, COUNT?: "COUNT", count?: stringable) => any;
    xtrim: (key: stringable, MAXLEN: "MAXLEN", tilde?: "~", count?: stringable) => any;
    xtrimBuffer: (key: stringable, MAXLEN: "MAXLEN", tilde?: "~", count?: stringable) => any;
    move: (key: stringable, db: stringable) => Promise<0 | 1>;
    moveBuffer: (key: stringable, db: stringable) => Promise<0 | 1>;
    rename: (key: stringable, newkey: stringable) => Promise<string>;
    renameBuffer: (key: stringable, newkey: stringable) => Promise<string>;
    renamenx: (key: stringable, newkey: stringable) => Promise<0 | 1>;
    renamenxBuffer: (key: stringable, newkey: stringable) => Promise<0 | 1>;
    expire: (key: stringable, seconds: stringable) => Promise<0 | 1>;
    expireBuffer: (key: stringable, seconds: stringable) => Promise<0 | 1>;
    pexpire: (key: stringable, milliseconds: stringable) => Promise<0 | 1>;
    pexpireBuffer: (key: stringable, milliseconds: stringable) => Promise<0 | 1>;
    expireat: (key: stringable, timestamp: stringable) => Promise<0 | 1>;
    expireatBuffer: (key: stringable, timestamp: stringable) => Promise<0 | 1>;
    migrate: (...args: stringable[]) => any;
    migrateBuffer: (...args: stringable[]) => any;
    object: (subcommand: stringable, ...args: stringable[]) => any;
    objectBuffer: (subcommand: stringable, ...args: stringable[]) => any;
    pexpireat: (key: stringable, millisecondsTimestamp: stringable) => Promise<0 | 1>;
    pexpireatBuffer: (key: stringable, millisecondsTimestamp: stringable) => Promise<0 | 1>;
    keys: (pattern: stringable) => Promise<string[]>;
    keysBuffer: (pattern: stringable) => Promise<string[]>;
    ttl: (key: stringable) => Promise<number>;
    ttlBuffer: (key: stringable) => Promise<number>;
    sort: (key: stringable, ...args: stringable[]) => any;
    sortBuffer: (key: stringable, ...args: stringable[]) => any;
    randomkey: () => Promise<string>;
    randomkeyBuffer: () => Promise<string>;
    persist: (key: stringable) => Promise<0 | 1>;
    persistBuffer: (key: stringable) => Promise<0 | 1>;
    type: (key: stringable) => Promise<string>;
    typeBuffer: (key: stringable) => Promise<string>;
    scan: (cursor: stringable, ...args: stringable[]) => [string, string[]];
    scanBuffer: (cursor: stringable, ...args: stringable[]) => [Buffer, Buffer[]];
    scanStream: (options?: ScanStreamOptions) => ScanStream;
    scanBufferStream: (options?: ScanStreamOptions) => ScanStream;
    scanIterable: (options?: ScanIterableOptions) => AsyncIterableIterator<string[]>;
    scanBufferIterable: (options?: ScanIterableOptions) => AsyncIterableIterator<Buffer[]>;
    auth: (password: stringable) => Promise<string>;
    authBuffer: (password: stringable) => Promise<string>;
    echo: (message: stringable) => Promise<string>;
    echoBuffer: (message: stringable) => Promise<string>;
    ping: (message?: stringable) => Promise<string>;
    pingBuffer: (message?: stringable) => Promise<string>;
    quit: () => Promise<string>;
    quitBuffer: () => Promise<string>;
    select: (index: stringable) => Promise<string>;
    selectBuffer: (index: stringable) => Promise<string>;
    swap: (sourceIndex: stringable, targetIndex: stringable) => Promise<string>;
    swapBuffer: (sourceIndex: stringable, targetIndex: stringable) => Promise<string>;
    eval: (...args: stringable[]) => any;
    evalBuffer: (...args: stringable[]) => any;
    evalsha: (...args: stringable[]) => any;
    evalshaBuffer: (...args: stringable[]) => any;
    script: (...args: stringable[]) => any;
    scriptBuffer: (...args: stringable[]) => any;
    subscribe: (...channels: stringable[]) => any;
    subscribeBuffer: (...channels: stringable[]) => any;
    unsubscribe: (...channels: stringable[]) => any;
    unsubscribeBuffer: (...channels: stringable[]) => any;
    psubscribe: (...patterns: stringable[]) => any;
    psubscribeBuffer: (...patterns: stringable[]) => any;
    punsubscribe: (...patterns: stringable[]) => any;
    punsubscribeBuffer: (...patterns: stringable[]) => any;
    publish: (channel: stringable, message: stringable) => Promise<number>;
    publishBuffer: (channel: stringable, message: stringable) => Promise<number>;
    dbsize: () => Promise<number>;
    dbsizeBuffer: () => Promise<number>;
    save: () => Promise<string>;
    saveBuffer: () => Promise<string>;
    bgsave: () => Promise<string>;
    bgsaveBuffer: () => Promise<string>;
    bgrewriteaof: () => Promise<string>;
    bgrewriteaofBuffer: () => Promise<string>;
    shutdown: (save: "SAVE" | "NOSAVE") => Promise<any>;
    shutdownBuffer: (save: "SAVE" | "NOSAVE") => Promise<any>;
    lastsave: () => Promise<number>;
    lastsaveBuffer: () => Promise<number>;
    exec: () => Promise<any>;
    execBuffer: () => Promise<any>;
    discard: () => Promise<any>;
    discardBuffer: () => Promise<any>;
    sync: () => Promise<any>;
    syncBuffer: () => Promise<any>;
    flushdb: () => Promise<string>;
    flushdbBuffer: () => Promise<string>;
    flushall: () => Promise<string>;
    flushallBuffer: () => Promise<string>;
    info: (section?: stringable) => Promise<string>;
    infoBuffer: (section?: stringable) => Promise<string>;
    time: () => Promise<any>;
    timeBuffer: () => Promise<any>;
    slaveof: (host: stringable, port: stringable) => Promise<string>;
    slaveofBuffer: (host: stringable, port: stringable) => Promise<string>;
    debug: (...args: stringable[]) => any;
    debugBuffer: (...args: stringable[]) => any;
    config: (...args: stringable[]) => any;
    configBuffer: (...args: stringable[]) => any;
    watch: (...keys: stringable[]) => any;
    watchBuffer: (...keys: stringable[]) => any;
    unwatch: () => Promise<string>;
    unwatchBuffer: () => Promise<string>;
    cluster: (...args: stringable[]) => any;
    clusterBuffer: (...args: stringable[]) => any;
    restore: (...args: stringable[]) => any;
    restoreBuffer: (...args: stringable[]) => any;
    client: (...args: stringable[]) => any;
    clientBuffer: (...args: stringable[]) => any;
    memory: (subcommand: stringable, key?: stringable) => any;
    memoryBuffer: (subcommand: stringable, key?: stringable) => any;
    wait: (numreplicas: stringable, timeout: stringable) => any;
    waitBuffer: (numreplicas: stringable, timeout: stringable) => any;
    connect: () => Promise<any>;
    disconnect: () => void;
    addListener: (event: stringable | symbol, listener: Function) => this;
    emit: (event: stringable | symbol, ...args: stringable[]) => boolean;
    eventNames: () => (string | symbol)[];
    getMaxListeners: () => number;
    listenerCount: (type: stringable | symbol) => number;
    listeners: (event: stringable | symbol) => Function[];
    off: (event: stringable | symbol, listener: (...args: stringable[]) => void) => this;
    on: (event: stringable | symbol, listener: Function) => this;
    once: (event: stringable | symbol, listener: Function) => this;
    prependListener: (event: stringable | symbol, listener: Function) => this;
    prependOnceListener: (event: stringable | symbol, listener: Function) => this;
    rawListeners: (event: stringable | symbol) => Function[];
    removeAllListeners: (event?: stringable | symbol) => this;
    removeListener: (event: stringable | symbol, listener: Function) => this;
    setMaxListeners: (n: stringable) => this;
}
